@@ -4,12 +4,11 @@ import unittest
 
 import testInits
 import middleware.testthreadlocals
-import fields.testaudit
 import fields.testdefaulting
 import fields.testscalingimagefield
 
 tests = [testInits.suite, middleware.testthreadlocals.suite, 
-         fields.testaudit.suite, fields.testdefaulting.suite, 
+         fields.testdefaulting.suite, 
          fields.testscalingimagefield.suite]
 suite = unittest.TestSuite(tests)
 
